
TODO: TODO_20_61_16_31 `cardinality_hook`: run different funcs based on `data_envelope` set size

If there are multiple `data_envelope` anywhere in `query_plan` (as last `data_envelope` or not),
it should be possible to hit enter and provide some meaningful action for the list of
these currently found `data_envelope`-s of the same single class
(even if function needs envelopes of subsequent classes).

If command accept one envelope, but not yet disambiguated, then it should be possible to provide generic hook to list envelopes based on existing filter.
Basically, if 1, invoke target function, if N, invoke list, print error to stderr, exit with non 0.

There can be two approaches:

*   Client-side: (simpler for `argrelay`)

    This can simply be implemented by checking `data_envelope` set size within `envelope_container`.
    Each delegator should support this its own way (or there could be some client-side dispatching utils).

*   Server-side: (simpler for users)

    Another way to approach this is to let server know expected cardinality and redirect invocation to
    some generic funcs which may list the object and provide common explanation.

See also:
*   TODO: TODO_86_57_50_38: (config-only for) common delegator behavior

